==> sdd.mercadopago2-0.2.1-sources.jar: ar/com/sdd/mercadopago/entity/customer/Shipment.java <==
package ar.com.sdd.mercadopago.entity.customer;

import java.util.ArrayList;
import java.util.Arrays;

/**
 * Mercado Pago SDK
 * Customer Address Verification Shipment class
 * <p>
 * Created by Eduardo Paoletta on 12/15/16.
 */
public class Shipment {

    private Boolean success = null;
    private ArrayList<Error> errors = null;
    private String name = null;


    public Boolean getSuccess() {
        return success;
    }

    public void setSuccess(Boolean success) {
        this.success = success;
    }

    public ArrayList<Error> getErrors() {
        return errors;
    }

    public void setErrors(ArrayList<Error> errors) {
        this.errors = errors;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }


    @Override
    public String toString() {
        return "Shipment ["
                + ((success != null) ? "success=" + success + ", " : "")
                + ((errors != null) ? "errors=" + Arrays.toString(errors.toArray()) + ", " : "")
                + ((name != null) ? "name=" + name : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Shipment shipment = (Shipment) o;

        if (success != null ? !success.equals(shipment.success) : shipment.success != null) return false;
        if (errors != null ? !errors.equals(shipment.errors) : shipment.errors != null) return false;
        return name != null ? name.equals(shipment.name) : shipment.name == null;
    }

    @Override
    public int hashCode() {
        int result = success != null ? success.hashCode() : 0;
        result = 31 * result + (errors != null ? errors.hashCode() : 0);
        result = 31 * result + (name != null ? name.hashCode() : 0);
        return result;
    }
}

==> sdd.mercadopago2-0.2.15-sources.jar: ar/com/sdd/mercadopago/entity/customer/Shipment.java <==
package ar.com.sdd.mercadopago.entity.customer;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.PropertyNamingStrategy;
import com.fasterxml.jackson.databind.annotation.JsonNaming;

import java.util.ArrayList;
import java.util.Arrays;

/**
 * Mercado Pago SDK
 * Customer Address Verification Shipment class
 * <p>
 * Created by Eduardo Paoletta on 12/15/16.
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonNaming(PropertyNamingStrategy.SnakeCaseStrategy.class)
public class Shipment {

    private Boolean success = null;
    private ArrayList<Error> errors = null;
    private String name = null;


    public Boolean getSuccess() {
        return success;
    }

    public void setSuccess(Boolean success) {
        this.success = success;
    }

    public ArrayList<Error> getErrors() {
        return errors;
    }

    public void setErrors(ArrayList<Error> errors) {
        this.errors = errors;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }


    @Override
    public String toString() {
        return "Shipment ["
                + ((success != null) ? "success=" + success + ", " : "")
                + ((errors != null) ? "errors=" + Arrays.toString(errors.toArray()) + ", " : "")
                + ((name != null) ? "name=" + name : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Shipment shipment = (Shipment) o;

        if (success != null ? !success.equals(shipment.success) : shipment.success != null) return false;
        if (errors != null ? !errors.equals(shipment.errors) : shipment.errors != null) return false;
        return name != null ? name.equals(shipment.name) : shipment.name == null;
    }

    @Override
    public int hashCode() {
        int result = success != null ? success.hashCode() : 0;
        result = 31 * result + (errors != null ? errors.hashCode() : 0);
        result = 31 * result + (name != null ? name.hashCode() : 0);
        return result;
    }
}
